(productionconfiguration)=

# Production Configuration

Modules provide functionality to configure a simulation production.
This includes the derivation of energy, viewcone radius, and core scatter ranges and
the calculation of the number of events to be simulated given a pre-determined metric.

(calculate-statistical-errors-grid-point)=

## calculate_statistical_uncertainties_grid_point

```{eval-rst}
.. automodule:: production_configuration.calculate_statistical_uncertainties_grid_point
   :members:
```


(derive-corsika-limits_grid)=

## derive_corsika_limits

```{eval-rst}
.. automodule:: production_configuration.derive_corsika_limits
   :members:
```

(derive-production-statistics)=

## derive_production_statistics

```{eval-rst}
.. automodule:: production_configuration.derive_production_statistics
   :members:
```

(derive-production-statistics-handler)=

## derive_production_statistics_handler

```{eval-rst}
.. automodule:: production_configuration.derive_production_statistics_handler
   :members:
```

(generate-production-grid)=

## generate_production_grid

```{eval-rst}
.. automodule:: production_configuration.generate_production_grid
   :members:
```

(interpolation-handler)=

## interpolation_handler

```{eval-rst}
.. automodule:: production_configuration.interpolation_handler
   :members:
```

(merge-corsika-limits)=

## merge_corsika_limits

```{eval-rst}
.. automodule:: production_configuration.merge_corsika_limits
   :members:
```
